@@ -6,8 +6,11 @@ DB_NAME='nauto'
 DATE_COL='daily_ts'
 DATE_UNIQ='serial_number'
 
+TRACE=True
+
 cAlias='|'
 kAbove='above'
+kAny='any'
 kArgs='args'
 kCast='as_number'
 kCols='cols'
@@ -18,6 +21,7 @@ kGroup='group'
 kInner='inner'
 kJoinType='join_type'
 kKeepJoin='keep_join'
+kMatch='matching'
 kReverse='descend'
 kSave='save'
 kSelect='select'
@@ -27,3 +31,4 @@ kSkipUpload='skip_upload'
 kSort='sort'
 kSQL='sql'
 kUniq='ensure_unique'
+kWhere='where'
